@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2018 Free Software Foundation, Inc.
+# Copyright (C) 2011-2025 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,6 +32,10 @@ test: all distdir
 	ls -l $(distdir)
 	echo ' ' $(DIST_COMMON) ' ' | grep '[ /]stamp-vti '
 	test -f $(distdir)/stamp-vti
+
+# The test can fail under a parallel make, so disable.
+# No evident way to debug or reliably reproduce.
+.NOTPARALLEL:
 END
 
 cat > foo.texi << 'END'
